/*! Parental Control V2.18 */
class Api {
    constructor() {
        this.version = chrome.app.getDetails().version;
        this.updateInterval = 25 * 60 * 1e3;
        this.beatInterval = 24 * 60 * 60 * 1e3;
        this.beatLastUpdate = 0;

        this.ignore_urls = ["chrome://", "chrome://extensions", "chrome-extension:",
            "chrome-search://",
            "http://parentalcontrol.site",
            "https://parentalcontrol.site",
            "chrome-devtools://", "chrome.google.com", "about:", "view-source:", "file://", 'parentalcontrol.site',
            "*.google.*",
            "//localhost", /analytics.*/];

        chrome.storage.onChanged.addListener(function (changes, namespace) {
            this.loadSettings();
        }.bind(this));

        this.controller = {
            adult: {
                words: [],
                sites: [],
                domains: []
            },
            tracker: {
                $ads: [],
                $social: [],
                $analytics: [],
                $sponsors: [],
                $spyware: []
            }
        };
    }

    loadSettings() {
        chrome.storage.local.get(null, function (items) {
            if (items.options.account.style == 1) {
                this.blockHost = chrome.extension.getURL("layouts/blocker1.html?url=");
            }
            if (items.options.account.style == 2) {
                this.blockHost = chrome.extension.getURL("layouts/blocker2.html?url=");
            }
            if (items.options.account.style == 3) {
                this.blockHost = chrome.extension.getURL("layouts/blocker3.html?url=");
            }
        }.bind(this));

    }

    checkUrl(url) {
        if (!url || url === "") {
            return false;
        }

        if (url.indexOf(this.blockHost) !== -1) {
            if (url.match(/url=*([^\n]*)/).length === 2) {
                return true;
            }
        }

        for (let i = 0, j = this.ignore_urls.length; i < j; i++) {
            if (url.indexOf(this.ignore_urls[i]) > -1) return false;
        }
        return true;
    }
}

const api = new Api();

