class Browser {
    constructor() {
        this.activeTracker = {};
        this.$pcd = "";
        chrome.storage.onChanged.addListener(function (changes, namespace) {
            chrome.storage.local.get('passcode', function (items) {
                this.$pcd = items.passcode;
            }.bind(this))
        }.bind(this));
        chrome.storage.local.get('passcode', function (items) {
            this.$pcd = items.passcode;
        }.bind(this))
    }

    activeSeed() {
        return {
            domain: "",
            online: 0,
            blocksite: 1,
            adult: 0,
            $ads: {}
        };
    }

    onMessage(request, sender, sendResponse) {
        switch (request.message) {
            case "getOptions": {
                let options = settings.options;
                options.pcd = this.$pcd;
                sendResponse(options);
                break;
            }
            case "saveSettings": {
                settings.setOptions(request.options);
                break;
            }
            case "saveBackupSettings": {
                settings.setBackupOptions(request.options);
                break;
            }
            case "getBackupSettings": {
                sendResponse(settings.backupOptions);
                break;
            }
            case "setOption": {
                settings.setOption(request.category, request.name, request.value);
                break;
            }
            case "setMasterOption": {
                for (let filter in settings.options.filters) {
                    settings.setOption("filters", filter, request.value);
                }
                break;
            }

            case "setPassword": {
                let enc = CryptoJS.AES.encrypt(request.value, "YHGFTJGF7Ls");
                chrome.storage.local.set({passcode: enc.toString()});

                chrome.storage.local.get("passcode", function (result) {
                    if (typeof result.passcode === "undefined") {
                        this.$pcd = "";
                    }
                    this.$pcd = result.passcode;
                });
                if (this.$pcd != "") {
                    settings.setOption("account", 'require', 1);
                }
                sendResponse("password has been set");
                break;
            }
            case "getPassword": {
                sendResponse(this.$pcd);
                break;
            }
            case "isBlockCss": {
                sendResponse({
                    options: settings.options,
                    tracker: this.activeTracker[request.domain]
                });
                break;
            }
            case "blockSite": {
                request.url = utils.getDomain(request.url);
                if (request.url == "parentalcontrol.site") {
                    return false;
                }

                if (!adult.isWhiteSite(request.url)) {
                    adult.blockSite(request, request.reason);
                }

            }

        }
    }

    updateButton(state, text) {
        if (state === 0 || typeof text == "undefined")
            text = "";

        if (text === 0 || text === -1)
            text = "";

        if (typeof text === "number")
            text = String(text);

        chrome.browserAction.setBadgeText({
            text: text
        });
    }

    findTrackerByTabId(tabId) {
        for (let domain in this.activeTracker) {
            let tracker = this.activeTracker[domain];
            if (tracker && tracker.tabIds && tracker.tabIds.indexOf(tabId) !== -1) {
                return tracker;
            }
        }
        return;
    }

    isBlockingPage(url) {
        if (!api.checkUrl(url)) return false;
        return false;
    }

    onSelectionChanged(tabId, changeInfo) {
        chrome.tabs.get(tabId, function (tab) {
            if (!tab || !api.checkUrl(tab.url)) {
                this.updateButton(0);
                return;
            } else {
                let domain = utils.getDomain(tab.url),
                    item = this.activeTracker[domain];

                if (item) {
                    if (item.adult === 1) {
                        this.updateButton(2);
                    } else if (item.online === 1) {
                        this.updateButton(1);
                    } else {
                        this.updateButton(0);
                    }
                    return;
                }
                item = jQuery.extend({}, this.activeSeed());
                item.domain = domain;
                item.tabIds = [];
                item.tabIds.push(tabId);
                item.tabIds = item.tabIds.unique();

                this.activeTracker[domain] = item;

                if (this.isBlockingPage(tab.url)) {
                    let request = {
                        url: tab.url,
                        tabId: tab.id
                    };
                    adult.blockSite(request);
                    this.updateButton(2);
                } else {
                    this.updateButton(0);
                }
            }
        }.bind(this));
    }

    onTabUpdated(tabId, changeInfo, tab) {
        if (!tab || !api.checkUrl(tab.url)) {
            this.updateButton(0);
            return;
        }
        if (tab.openerTabId) {
            tabId = tab.openerTabId;
        }
        let domain = "";
        let tracker = this.findTrackerByTabId(tabId);
        if (!tracker && !changeInfo.url) {

            domain = utils.getDomain(tab.url);

            this.activeDomain = domain;
            let item = this.activeTracker[domain];
            if (item && tab.openerTabId) {
                item.tabIds.push(tab.openerTabId);
                item.tabIds = item.tabIds.unique();
                this.activeTracker[domain] = item;
                this.updateButton(1);
                return;
            }
            item = jQuery.extend({}, this.activeSeed());
            item.domain = domain;
            item.tabIds = [];
            item.tabIds.push(tabId);
            item.tabIds = item.tabIds.unique();
            item.tabIds = item.tabIds.unique();
            this.activeTracker[domain] = item;
        }
        if (changeInfo.url) {
            domain = utils.getDomain(changeInfo.url);
            this.activeDomain = domain;
            let item = this.activeTracker[domain];
            if (item !== tracker) {
                if (item) {
                    item.tabIds.push(tab.id);
                    item.tabIds = item.tabIds.unique();
                    this.activeTracker[domain] = item;
                    this.updateButton(1);
                    return;
                } else {
                    item = jQuery.extend({}, this.activeSeed());
                    item.domain = domain;
                    item.tabIds = [];
                    item.tabIds.push(tab.id);
                    item.tabIds = item.tabIds.unique();
                    this.activeTracker[domain] = item;
                }
            }
        }
    }

    onRemoved(tabId) {
        let tracker = this.findTrackerByTabId(tabId);
        if (tracker) {
            let index = tracker.tabIds.indexOf(tabId);
            if (index !== -1) {
                if (tracker.tabIds.length === 1) {
                    /**
                     * @todo error
                     */
                    delete this.activeTracker[tracker.domain];
                } else {
                    tracker.tabIds.splice(index, 1);
                }
            }
        }
    }

    work() {
        chrome.extension.onMessage.addListener(this.onMessage.bind(this));
        chrome.tabs.onSelectionChanged.addListener(this.onSelectionChanged.bind(this));
        chrome.tabs.onUpdated.addListener(this.onTabUpdated.bind(this));
        chrome.tabs.onRemoved.addListener(this.onRemoved.bind(this));

        chrome.storage.local.get("passcode", function (result) {
            if (typeof result.passcode === "undefined") {
                this.$pcd = "";
            }
            this.$pcd = result.passcode;
        }.bind(this));

    }
}

const browser = new Browser();

$(document).ready(function () {
    browser.work();
});