/*! Parental Control V2.18 */
class Popup {
    constructor() {
        this.domain = "";
        this.tabId = -1;
        this.translate();
        this.initialize();
        this.helpUrl = "https://parentalcontrol.site/help";
        this.paymentlink = "https://parentalcontrol.site/donate.html";

        $("#help").on("click", function () {
            chrome.tabs.create({'url': this.helpUrl}, function (tab) {
            }.bind(this));
        }.bind(this))

        $("#paymentlink").on("click", function () {
            chrome.tabs.create({'url': this.paymentlink}, function (tab) {
            }.bind(this));
        }.bind(this));

        $("#rate").on("click", function () {
            chrome.tabs.create({'url': "https://chrome.google.com/webstore/detail/parental-control-adult-bl/peocghcbolghcodidjgkndgahnlaecfl"}, function (tab) {
            }.bind(this));
        }.bind(this))
    }

    translate() {
        $("[data-i18n]").each(function (index) {
            $(this).html(chrome.i18n.getMessage($(this).data("i18n")));
        })
    }

    getDomain(url) {
        if (url === null)
            return url;
        return this.parseUrl(url).hostname
    }


    parseQuery(queryString) {
        let query = {},
            pairs = (queryString[0] === '?' ? queryString.substr(1) : queryString).split('&');

        for (let i = 0; i < pairs.length; i++) {
            let pair = pairs[i].split('=');
            query[i] = decodeURIComponent(pair[1] || '');
        }
        return query;
    }

    parseUrl(url) {
        let a = document.createElement('a');
        a.href = url;
        return a;
    }

    initialize() {
        chrome.tabs.getSelected(null, function (request) {
            this.tabId = request.id;
            this.domain = this.getDomain(request.url);

            if (this.domain == chrome.runtime.id) {
                let x = this.parseQuery(request.url);
                this.domain = x[0];
            }

            $("#domain").html(this.domain);

            if (this.domain === "" || this.domain.length === 0) {
                $("#block").addClass("disabled");
                $("#allow").addClass("disabled");
            }
        }.bind(this));

        chrome.extension.sendMessage({message: "getOptions"}, function (options) {
            let master = options.filters.$master,
                pwd_require = options.account.require;
            if (pwd_require === 1) {
                $("#allowed-mode").css("display", "none");
                $("#blocked-mode").css("display", "block");
            } else {
                $("#allowed-mode").css("display", "block");
                $("#blocked-mode").css("display", "none");
            }
            //master
            $("#onOFF").attr("class", (master == 1) ? "on" : "off");
            if (master == 1) {
                $("#onOFF").attr("src", 'assets/images/on.png').attr('title', chrome.i18n.getMessage("disable_porn_blocker"))
                $("#onOFF").parent().attr('title', chrome.i18n.getMessage("disable_porn_blocker"));
                $(".recorder-options").css({opacity: 1})
            } else {
                $("#onOFF").attr("src", 'assets/images/off.png').attr('title', chrome.i18n.getMessage("enable_porn_blocker"))
                $("#onOFF").parent().attr('title', chrome.i18n.getMessage("enable_porn_blocker"));
                $(".recorder-options").css({opacity: 0.5});

            }
        }.bind(this));

        $("#onOFF").on('click', function (e) {
            if (e.target.getAttribute("class") == "on") {
                e.target.setAttribute("class", "off");
                $("#onOFF").attr("class", "off");
            } else {
                e.target.setAttribute("class", "on");
                $("#onOFF").attr("class", "on");
            }
            let val = e.target.getAttribute("class") == "on" ? 1 : 0;
            if (val == 1) {
                $("#onOFF").attr("src", 'assets/images/on.png')
                $("#onOFF").parent().attr('title', chrome.i18n.getMessage("disable_porn_blocker"));
                $("#onOFF").attr('title', chrome.i18n.getMessage("disable_porn_blocker"));
                $(".recorder-options").css({opacity: 1})
            } else {
                $("#onOFF").attr("src", 'assets/images/off.png');
                $("#onOFF").parent().attr('title', chrome.i18n.getMessage("enable_porn_blocker"));
                $("#onOFF").attr('title', chrome.i18n.getMessage("enable_porn_blocker"));
                $(".recorder-options").css({opacity: 0.5})
            }

            chrome.runtime.sendMessage({message: "setMasterOption", value: val});
        })

        $("#validate-pwd").unbind().keypress(function (e) {
            if (e.keyCode == 13) {
                $("#validate-pwd-button").click();
            }
        });
        $("#validate-pwd-button").on("click", function (e) {
            chrome.extension.sendMessage({
                message: "getPassword"
            }, function (passcode) {
                let encrypted = passcode,
                    bytes = CryptoJS.AES.decrypt(encrypted.toString(), "YHGFTJGF7Ls"),
                    plain = bytes.toString(CryptoJS.enc.Utf8);

                if (plain !== $("#validate-pwd").val()) {
                    alert("wrong Password!");
                    $("$validate-pwd").focus();
                } else {
                    $("#allowed-mode").css("display", "block");
                    $("#blocked-mode").css("display", "none");
                }
            });
        }.bind(this));

        $("#block").on('click', function (e) {
            chrome.extension.sendMessage({
                message: "addToBlackList",
                url: this.domain,
                tab: this.tabId
            });
        }.bind(this));

        $("#allow").on("click", function (e) {
            chrome.extension.sendMessage({
                message: "addToWhiteList",
                url: this.domain,
                tab: this.tabId
            });
        }.bind(this));

        $("#submit").on("click", function (e) {
            chrome.tabs.create({
                url: chrome.extension.getURL("options.html?submit=1"),
                active: true
            });
        });

        $("#settings").on("click", function (e) {
            chrome.tabs.create({
                url: chrome.extension.getURL("options.html"),
                active: true
            });
        });
    }
}

$(document).ready(function () {
    new Popup();
});