/*! Parental Control V2.18 */
class Settings {
    constructor() {
        this.options = {
            filters: {
                $master: 1,
                $adult: 1,
                $ads: 0,
                $block: 1,
                $trust: 1
            },
            forcesafe: {
                bing: 1,
                google: 1,
                yahoo: 1,
                youtube: 1
            },
            search: {
                bing: 1,
                google: 1,
                yahoo: 1,
                suspicious: 1
            },
            account: {
                require: 0,
                block: 1,
                trust: 1,
                hide_icon: 0,
                style: 1,
                hide_context_menu: 1
            }
        };
        this.backupOptions = null;
    }

    setOptions(options) {
        this.options = options;
        chrome.storage.local.set({options: this.options}, function () {
        });
    }

    setBackupOptions(options) {
        this.backupOptions = options;
        chrome.storage.local.set({
            backupOptions: options
        }, function () {
        });
    }

    setOption(category, name, value) {
        this.options[category][name] = value;
        chrome.storage.local.set({options: this.options}, function () {
        });
    }

    work() {
        chrome.storage.local.get("options", function (result) {
            try {
                if (typeof result.options == "undefined") {
                    chrome.storage.local.set({options: this.options}, function () {
                    });
                } else {
                    this.options = result.options;
                }
            } catch (ex) {
            }
        }.bind(this));

        chrome.storage.onChanged.addListener(function (changes, namespace) {
            chrome.storage.local.get(null, function (items) {
                this.options = items.options;
            }.bind(this))
        }.bind(this));

        chrome.storage.local.get("backupOptions", function (result) {
            try {
                if (typeof result.backupOptions == "undefined") {
                    chrome.storage.local.set({
                        backupOptions: this.options
                    }, function () {
                    });
                } else {
                    this.backupOptions = result.backupOptions;
                }
            } catch (ex) {
            }
        }.bind(this));
    }

    uid() {
        let buf = new Uint32Array(4),
            idx = -1;
        window.crypto.getRandomValues(buf);
        let uid = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
            idx++;
            let r = (buf[idx >> 3] >> ((idx % 8) * 4)) & 15,
                v = c == 'x' ? r : (r & 0x3 | 0x8);
            return v.toString(16);
        });
        return uid;
    }

    onInstalled() {
        chrome.runtime.setUninstallURL("https://parentalcontrol.site/uninstall");
        chrome.runtime.onInstalled.addListener(function (details) {
            if (details.reason == "install") {
                chrome.storage.local.set({
                    installDate: (new Date()).getTime(),
                    uid: this.uid()
                });
                chrome.storage.local.set({options: this.options}, function () {});
                chrome.tabs.getSelected(null, function (tab) {
                    chrome.tabs.update(tab.id, {url: `options.html?message=1`});
                }.bind(this));
                chrome.tabs.create({ url: "https://parentalcontrol.site/help", active: true, selected: false });
            } else if (details.reason == "update") {
                chrome.storage.local.set({updateDate: (new Date()).getTime()});
                chrome.storage.local.set({options: this.options}, function () {});

            }
        }.bind(this));
    }


}

const settings = new Settings();
(function () {
    settings.onInstalled();
    settings.work();
})();
